<?php
declare (strict_types = 1);

namespace app\admin\controller;

use app\BaseController;
use think\facade\Db;

class User extends BaseController
{
    /**
     * 显示资源列表
     *
     * @return \think\Response
     */
    public function list()
    {
        $post  =$this->request->post();
        $token = isset($post['token']) ? trim($post['token']) : "";
        if($token==""){
            return error_show(101,'token不能为空');
        }
        $effetc =VerifyTokens($token);
        if(!empty($effetc) && $effetc['code']!=0){
            return error_show($effetc['code'],$effetc['message']);
        }
        $page = isset($post['page'])&& $post['page']!='' ? intval($post['page']) : 1;
        $size = isset($post['size'])&& $post['size']!='' ? intval($post['size']) : 10;
        $condition = ['page'=>$page,'size'=>$size];
        $data = Getlist($token,$condition);
        if(!empty($data) && $data['code']!=0){
            return error_show($effetc['code'],$effetc['message']);
        }
        $list=[];
        foreach($data['data']['list'] as $key=>$value){
            $role = Db::name("user_role")->alias('a')->leftJoin('role b',"a.roleid = b.id")->where("a.uid","=",$value['id'])
                ->field("roleid,role_name")->find();
            $value['roleid'] = isset($role['roleid']) ? $role['roleid'] :"";
            $value['role_name'] = isset($role['role_name']) ? $role['role_name'] :"";
            $list[]=$value;
        }
        $data['data']['list'] = $list;
        return app_show($data['code'],$data['message'],$data['data']);
    }

    /**
     * @param token
     * @return \think\response\Json
     * @throws \think\exception\DbException
     */
    public function userInfo(){
        $post  =$this->request->post();
        $token = isset($post['token']) ? trim($post['token']) : "";
        if($token==""){
            return app_show(101,'token不能为空');
        }

        $effetc = VerifyTokens($token);
        if(!empty($effetc) && $effetc['code']!=0){
            return app_show($effetc['code'],$effetc['message']);
        }
        $userinfo=GetUserInfo($token);
        if(empty($userinfo)||$userinfo['code']!=0){
            return app_show(1002,"员工信息不存在");
        }
        $data = $userinfo['data'];
        $role = Db::name("user_role")->alias('a')->leftJoin('role b',"a.roleid = b.id")->where("a.uid","=",$data['id'])
            ->field("roleid,role_name")->find();
        $data['role_name']=isset($role['role_name']) ? $role['role_name'] :"";
        $data['roleid']=isset($role['roleid']) ? $role['roleid'] :"";
        $depart = Db::name("depart_user")->where([["uid","=",$data['uid']],["is_del","=",0]])->column("itemid");
        $data['depart']="";
        if(!empty($depart)){
            $deparname = Db::name("company_item")->where(["id"=>$depart,"is_del"=>0])->column("name");
            $data['depart'] = implode(",",$deparname);
        }
        return app_show(0,"获取成功",$data);
    }
    /**
     * @param  token
     * @param  passwd
     * @return \think\response\Json
     * @throws \think\exception\DbException
     */
    public function  resetPwd(){
        $post  =$this->request->post();
        $token = isset($post['token']) ? trim($post['token']) : "";
        if($token==""){
            return error_show(101,'token不能为空');
        }
        $effetc = verfiyToken($token);
        if(!empty($effetc) && $effetc['code']!=0){
            return error_show($effetc['code'],$effetc['message']);
        }
        $newPwd= isset($post['newpwd']) ? trim($post['newpwd']) : "";
        if($newPwd==""){
            return error_show(1001,'新密码不能为空');
        }
        $oldpwd = isset($post['oldpwd'])?trim($post['oldpwd']):"";
        if($oldpwd==""){
            return error_show(1002,"原密码不能为空");
        }
        $data = resetpasswd($token,['newpwd'=>$newPwd,'oldpwd'=>$oldpwd]);
    }

    public  function  userAll(){
        $post  =$this->request->post();
        $token = isset($post['token']) ? trim($post['token']) : "";
        if($token==""){
            return app_show(101,'token不能为空');
        }
        $effetc = VerifyTokens($token);
        if(!empty($effetc) && $effetc['code']!=0){
            return app_show($effetc['code'],$effetc['message']);
        }
        $userinfo=GetAccountall($token);

        if(empty($userinfo)||$userinfo['code']!=0){
            return app_show(1002,"员工信息不存在");
        }
        $data = $userinfo['data'];
        $role = Db::name("role")->column("role_name","id");
        $role[0]="";
        $list=[];
        foreach ($data as $value){
            $value["role_name"] = isset($role[$value["roleid"]]) ? $role[$value["roleid"]]:"";
            $list[]=$value;
        }
        return app_show(0,"获取成功",$list);
    }

    /**
     * @return \think\response\Json|void
     * @throws \think\db\exception\DataNotFoundException
     * @throws \think\db\exception\DbException
     * @throws \think\db\exception\ModelNotFoundException
     * @throws \think\exception\DbException
     */
    public  function  userList(){
        $post  =$this->request->post();
        $token = isset($post['token']) ? trim($post['token']) : "";
        if($token==""){
            return app_show(101,'token不能为空');
        }
        $effetc = VerifyTokens($token);
        if(!empty($effetc) && $effetc['code']!=0){
            return app_show($effetc['code'],$effetc['message']);
        }
        $userinfo=GetList($token,$post);
        if(empty($userinfo)||$userinfo['code']!=0){
            return app_show($userinfo['code'],$userinfo['msg']);
        }
        $data = $userinfo['data']['list'];
        $list=[];
        foreach ($data as $value){
            $role = Db::name("user_role")->alias('a')->leftJoin('role b',"a.roleid = b.id")->where("a.uid","=",$value['id'])
                ->field("roleid,role_name")->find();
            $value['roleid'] = isset($role['roleid']) ? $role['roleid'] :"";
            $value['role_name'] = isset($role['role_name']) ? $role['role_name'] :"";
            $list[]=$value;
        }
        return app_show(0,"获取成功",["list"=>$list,"count"=>$userinfo['data']["count"]]);
    }


    public function setRole(){
        $post  =$this->request->post();
        $token = isset($post['token']) ? trim($post['token']) : "";
        if($token==""){
            return app_show(101,'token不能为空');
        }
        $effetc = VerifyTokens($token);
        if(!empty($effetc) && $effetc['code']!=0){
            return app_show($effetc['code'],$effetc['message']);
        }
        $uid = isset($post['id'])&&$post['id']!=='' ? intval($post['id']) :"";
        if($uid===''){
            return error_show(1004,"参数id 不能为空");
        }
        $role =isset($post['roleid']) && $post['roleid']!=="" ? intval($post['roleid']) :"";
        if($role===''){
            return error_show(1004,"参数roleid 不能为空");
        }
        $isRole = Db::name('role')->where([['id',"=",$role],['status',"=",1]])->find();
        if(empty($isRole)){
            return error_show(1004,"所选角色不存在");
        }
        $data = [
            'uid'=>$uid,
            'roleid'=>$role,
            'status'=>1,
            'addtime'=>date('Y-m-d H:i:s'),
            'updatetime'=>date('Y-m-d H:i:s'),
        ];
        $insert = Db::name('user_role')->insert($data);

        return $insert? app_show(0,'数据新建成功'):error_show(1004,'数据新建失败');
    }
}
